/* This file is part of the KDE project
   Copyright (C) 2002 David Faure <faure@kde.org>
                 2002 Laurent Montel <lmontel@mandrakesoft.com>
                 2004 Zack Rusin <zack@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef kwbgspellcheck_h
#define kwbgspellcheck_h

class KWDocument;
class KWTextFrameSet;

#include "kobgspellcheck.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <qobject.h>
#ifdef HAVE_LIBKSPELL2
class KWBgSpellCheck : public KoBgSpellCheck
{
public:
    KWBgSpellCheck(KWDocument *_doc);
    virtual ~KWBgSpellCheck();

    virtual KoTextIterator *createWholeDocIterator() const;

private:
    KWDocument *m_doc;
    KWTextFrameSet *m_currentFrame;
};
#endif

#endif
